##  Step 1: Start the Mapping Wizard
  1. Navigate to the integration configuration page.
  2. On the Mapping tab, in the Relation Mapping section, choose Add Mapping.
  3. The mapping wizard guides you through four configuration steps.
